You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@manifoldcf.apache.org by kw...@apache.org on 2010/10/04 16:32:28 UTC

svn commit: r1004255 [3/24] - in /incubator/lcf/trunk: modules/connectors/activedirectory/connector/src/main/java/org/apache/manifoldcf/authorities/authorities/activedirectory/ modules/connectors/documentum/connector/src/main/java/org/apache/manifoldcf...

Modified: incubator/lcf/trunk/modules/connectors/gts/connector/src/main/java/org/apache/manifoldcf/agents/output/gts/HttpPoster.java
URL: http://svn.apache.org/viewvc/incubator/lcf/trunk/modules/connectors/gts/connector/src/main/java/org/apache/manifoldcf/agents/output/gts/HttpPoster.java?rev=1004255&r1=1004254&r2=1004255&view=diff
==============================================================================
--- incubator/lcf/trunk/modules/connectors/jcifs/connector/src/main/java/org/apache/manifoldcf/crawler/connectors/sharedrive/GetConnectionInfo.java (original)
+++ incubator/lcf/trunk/modules/connectors/jcifs/connector/src/main/java/org/apache/manifoldcf/crawler/connectors/sharedrive/GetConnectionInfo.java Mon Oct  4 14:32:19 2010
@@ -22,7 +22,7 @@ import org.apache.manifoldcf.core.interf
 import org.apache.manifoldcf.agents.interfaces.*;
 import org.apache.manifoldcf.crawler.interfaces.*;
 import org.apache.manifoldcf.crawler.system.Logging;
-import org.apache.manifoldcf.crawler.system.ACF;
+import org.apache.manifoldcf.crawler.system.ManifoldCF;
 
 public class GetConnectionInfo
 {
@@ -48,15 +48,15 @@ public class GetConnectionInfo
 
     try
     {
-      ACF.initializeEnvironment();
+      ManifoldCF.initializeEnvironment();
       IThreadContext tc = ThreadContextFactory.make();
       IRepositoryConnectionManager connectionManager = RepositoryConnectionManagerFactory.make(tc);
       IRepositoryConnection connection = connectionManager.load(connectionName);
       if (connection == null)
-        throw new ACFException("Connection "+connectionName+" does not exist");
+        throw new ManifoldCFException("Connection "+connectionName+" does not exist");
 
       if (connection.getClassName() == null || !connection.getClassName().equals("org.apache.manifoldcf.crawler.connectors.sharedrive.SharedDriveConnector"))
-        throw new ACFException("Command can only be used on working share connector connections.");
+        throw new ManifoldCFException("Command can only be used on working share connector connections.");
 
       ConfigParams cfg = connection.getConfigParams();
 

Modified: incubator/lcf/trunk/modules/connectors/jcifs/connector/src/main/java/org/apache/manifoldcf/crawler/connectors/sharedrive/MatchMap.java
URL: http://svn.apache.org/viewvc/incubator/lcf/trunk/modules/connectors/jcifs/connector/src/main/java/org/apache/manifoldcf/crawler/connectors/sharedrive/MatchMap.java?rev=1004255&r1=1004254&r2=1004255&view=diff
==============================================================================
--- incubator/lcf/trunk/modules/connectors/jcifs/connector/src/main/java/org/apache/manifoldcf/crawler/connectors/sharedrive/MatchMap.java (original)
+++ incubator/lcf/trunk/modules/connectors/jcifs/connector/src/main/java/org/apache/manifoldcf/crawler/connectors/sharedrive/MatchMap.java Mon Oct  4 14:32:19 2010
@@ -261,7 +261,7 @@ public class MatchMap
   /** Perform a translation.
   */
   public String translate(String input)
-    throws ACFException
+    throws ManifoldCFException
   {
     // Build pattern vector if not already there
     if (matchPatterns == null)
@@ -278,7 +278,7 @@ public class MatchMap
         catch (java.util.regex.PatternSyntaxException e)
         {
           matchPatterns = null;
-          throw new ACFException("For match expression '"+regexp+"', found pattern syntax error: "+e.getMessage(),e);
+          throw new ManifoldCFException("For match expression '"+regexp+"', found pattern syntax error: "+e.getMessage(),e);
         }
         i++;
       }

Modified: incubator/lcf/trunk/modules/connectors/jcifs/connector/src/main/java/org/apache/manifoldcf/crawler/connectors/sharedrive/SharedDriveConnector.java
URL: http://svn.apache.org/viewvc/incubator/lcf/trunk/modules/connectors/jcifs/connector/src/main/java/org/apache/manifoldcf/crawler/connectors/sharedrive/SharedDriveConnector.java?rev=1004255&r1=1004254&r2=1004255&view=diff
==============================================================================
--- incubator/lcf/trunk/modules/connectors/jcifs/connector/src/main/java/org/apache/manifoldcf/crawler/connectors/sharedrive/SharedDriveConnector.java (original)
+++ incubator/lcf/trunk/modules/connectors/jcifs/connector/src/main/java/org/apache/manifoldcf/crawler/connectors/sharedrive/SharedDriveConnector.java Mon Oct  4 14:32:19 2010
@@ -16,7 +16,7 @@
 */
 package org.apache.manifoldcf.crawler.connectors.sharedrive;
 
-import org.apache.manifoldcf.crawler.system.ACF;
+import org.apache.manifoldcf.crawler.system.ManifoldCF;
 import java.io.FileOutputStream;
 import java.io.FileInputStream;
 import java.io.File;
@@ -45,7 +45,7 @@ import org.apache.manifoldcf.core.interf
 import org.apache.manifoldcf.core.interfaces.IHTTPOutput;
 import org.apache.manifoldcf.core.interfaces.IPostParameters;
 import org.apache.manifoldcf.core.interfaces.ConfigParams;
-import org.apache.manifoldcf.core.interfaces.ACFException;
+import org.apache.manifoldcf.core.interfaces.ManifoldCFException;
 import org.apache.manifoldcf.core.interfaces.IKeystoreManager;
 import org.apache.manifoldcf.core.interfaces.KeystoreManagerFactory;
 import org.apache.manifoldcf.core.interfaces.Configuration;
@@ -57,7 +57,7 @@ import org.apache.manifoldcf.crawler.int
 import org.apache.manifoldcf.core.interfaces.SpecificationNode;
 import org.apache.manifoldcf.crawler.interfaces.IVersionActivity;
 import org.apache.manifoldcf.crawler.system.Logging;
-import org.apache.manifoldcf.crawler.system.ACF;
+import org.apache.manifoldcf.crawler.system.ManifoldCF;
 
 /** This is the "repository connector" for a smb/cifs shared drive file system.  It's a relative of the share crawler, and should have
 * comparable basic functionality.
@@ -123,7 +123,7 @@ public class SharedDriveConnector extend
   public SharedDriveConnector()
   {
     // We need to know whether to operate in NTLMv2 mode, or in NTLM mode.
-    String value = ACF.getProperty(PROPERTY_JCIFS_USE_NTLM_V1);
+    String value = ManifoldCF.getProperty(PROPERTY_JCIFS_USE_NTLM_V1);
     if (value == null || value.toLowerCase().equals("false"))
     {
       System.setProperty("jcifs.smb.lmCompatibility","3");
@@ -138,13 +138,13 @@ public class SharedDriveConnector extend
 
   /** Establish a "session".  In the case of the jcifs connector, this just builds the appropriate smbconnectionPath string, and does the necessary checks. */
   protected void getSession()
-    throws ACFException
+    throws ManifoldCFException
   {
     if (smbconnectionPath == null)
     {
       // Get the server
       if (server == null || server.length() == 0)
-        throw new ACFException("Missing parameter '"+SharedDriveParameters.server+"'");
+        throw new ManifoldCFException("Missing parameter '"+SharedDriveParameters.server+"'");
 
       // make the smb connection to the server
       String authenticationString;
@@ -164,7 +164,7 @@ public class SharedDriveConnector extend
       catch (MalformedURLException e)
       {
         Logging.connectors.error("Unable to access SMB/CIFS share: "+"smb://" + ((domain==null)?"":domain)+";"+username+":<password>@"+ server + "/\n" + e);
-        throw new ACFException("Unable to access SMB/CIFS share: "+server, e, ACFException.REPOSITORY_CONNECTION_ERROR);
+        throw new ManifoldCFException("Unable to access SMB/CIFS share: "+server, e, ManifoldCFException.REPOSITORY_CONNECTION_ERROR);
       }
     }
   }
@@ -192,7 +192,7 @@ public class SharedDriveConnector extend
   /** Close the connection.  Call this before discarding the repository connector.
   */
   public void disconnect()
-    throws ACFException
+    throws ManifoldCFException
   {
     server = null;
     domain = null;
@@ -266,7 +266,7 @@ public class SharedDriveConnector extend
   * @return the document uri.
   */
   protected static String convertToURI(String documentIdentifier, MatchMap fileMap, MatchMap uriMap)
-    throws ACFException
+    throws ManifoldCFException
   {
     //
     // Note well: This MUST be a legal URI!!
@@ -313,7 +313,7 @@ public class SharedDriveConnector extend
       catch (java.io.UnsupportedEncodingException e)
       {
         // Should not happen...
-        throw new ACFException(e.getMessage(),e);
+        throw new ManifoldCFException(e.getMessage(),e);
       }
     }
     else
@@ -365,7 +365,7 @@ public class SharedDriveConnector extend
       catch (java.io.UnsupportedEncodingException e)
       {
         // Should not happen...
-        throw new ACFException(e.getMessage(),e);
+        throw new ManifoldCFException(e.getMessage(),e);
       }
     }
   }
@@ -378,7 +378,7 @@ public class SharedDriveConnector extend
   *@return true if the resource is found, false if not.  In either case, output may be filled in.
   */
   public boolean requestInfo(Configuration output, String command)
-    throws ACFException
+    throws ManifoldCFException
   {
     if (command.startsWith("folders/"))
     {
@@ -395,9 +395,9 @@ public class SharedDriveConnector extend
           output.addChild(output.getChildCount(),node);
         }
       }
-      catch (ACFException e)
+      catch (ManifoldCFException e)
       {
-        ACF.createErrorNode(output,e);
+        ManifoldCF.createErrorNode(output,e);
       }
     }
     else if (command.startsWith("folder/"))
@@ -413,9 +413,9 @@ public class SharedDriveConnector extend
           output.addChild(output.getChildCount(),node);
         }
       }
-      catch (ACFException e)
+      catch (ManifoldCFException e)
       {
-        ACF.createErrorNode(output,e);
+        ManifoldCF.createErrorNode(output,e);
       }
     }
     else
@@ -437,7 +437,7 @@ public class SharedDriveConnector extend
   *@return the stream of local document identifiers that should be added to the queue.
   */
   public IDocumentIdentifierStream getDocumentIdentifiers(DocumentSpecification spec, long startTime, long endTime)
-    throws ACFException, ServiceInterruption
+    throws ManifoldCFException, ServiceInterruption
   {
     getSession();
     return new IdentifierStream(spec);
@@ -463,7 +463,7 @@ public class SharedDriveConnector extend
   */
   public String[] getDocumentVersions(String[] documentIdentifiers, String[] oldVersions, IVersionActivity activities,
     DocumentSpecification spec, int jobMode, boolean usesDefaultAuthority)
-    throws ACFException, ServiceInterruption
+    throws ManifoldCFException, ServiceInterruption
   {
     getSession();
     // Read the forced acls.  A null return indicates that security is disabled!!!
@@ -610,7 +610,7 @@ public class SharedDriveConnector extend
       catch (MalformedURLException mue)
       {
         Logging.connectors.error("JCIFS: MalformedURLException thrown: "+mue.getMessage(),mue);
-        throw new ACFException("MalformedURLException thrown: "+mue.getMessage(),mue);
+        throw new ManifoldCFException("MalformedURLException thrown: "+mue.getMessage(),mue);
       }
       catch (SmbException se)
       {
@@ -626,7 +626,7 @@ public class SharedDriveConnector extend
       }
       catch (InterruptedIOException e)
       {
-        throw new ACFException("Interrupted: "+e.getMessage(),e,ACFException.INTERRUPTED);
+        throw new ManifoldCFException("Interrupted: "+e.getMessage(),e,ManifoldCFException.INTERRUPTED);
       }
       catch (IOException e)
       {
@@ -662,7 +662,7 @@ public class SharedDriveConnector extend
   *            methods.
   */
   public void processDocuments(String[] documentIdentifiers, String[] versions, IProcessActivity activities,
-    DocumentSpecification spec, boolean[] scanOnly) throws ACFException, ServiceInterruption
+    DocumentSpecification spec, boolean[] scanOnly) throws ManifoldCFException, ServiceInterruption
   {
     getSession();
 
@@ -855,7 +855,7 @@ public class SharedDriveConnector extend
         Logging.connectors.error("MalformedURLException tossed",mue);
         activities.recordActivity(null,ACTIVITY_ACCESS,
           null,documentIdentifier,"Error","Malformed URL: "+mue.getMessage(),null);
-        throw new ACFException("MalformedURLException tossed: "+mue.getMessage(),mue);
+        throw new ManifoldCFException("MalformedURLException tossed: "+mue.getMessage(),mue);
       }
       catch (jcifs.smb.SmbAuthException e)
       {
@@ -876,7 +876,7 @@ public class SharedDriveConnector extend
           // See if it's an interruption
           jcifs.util.transport.TransportException te = (jcifs.util.transport.TransportException)cause;
           if (te.getRootCause() != null && te.getRootCause() instanceof java.lang.InterruptedException)
-            throw new ACFException(te.getRootCause().getMessage(),te.getRootCause(),ACFException.INTERRUPTED);
+            throw new ManifoldCFException(te.getRootCause().getMessage(),te.getRootCause(),ManifoldCFException.INTERRUPTED);
 
           Logging.connectors.warn("JCIFS: Timeout processing document/directory "+documentIdentifier+": retrying...",se);
           activities.recordActivity(null,ACTIVITY_ACCESS,
@@ -937,7 +937,7 @@ public class SharedDriveConnector extend
           Logging.connectors.error("JCIFS: SmbException tossed processing "+documentIdentifier,se);
           activities.recordActivity(null,ACTIVITY_ACCESS,
             null,documentIdentifier,"Error","Unknown: "+se.getMessage(),null);
-          throw new ACFException("SmbException tossed: "+se.getMessage(),se);
+          throw new ManifoldCFException("SmbException tossed: "+se.getMessage(),se);
         }
       }
       catch (java.net.SocketTimeoutException e)
@@ -951,7 +951,7 @@ public class SharedDriveConnector extend
       }
       catch (InterruptedIOException e)
       {
-        throw new ACFException("Interrupted: "+e.getMessage(),e,ACFException.INTERRUPTED);
+        throw new ManifoldCFException("Interrupted: "+e.getMessage(),e,ManifoldCFException.INTERRUPTED);
       }
       catch (IOException e)
       {
@@ -975,7 +975,7 @@ public class SharedDriveConnector extend
   */
   protected void describeDocumentSecurity(StringBuffer description, SmbFile file, String[] forcedacls,
     String[] forcedShareAcls)
-    throws ACFException, IOException
+    throws ManifoldCFException, IOException
   {
     String[] shareAllowAcls;
     String[] shareDenyAcls;
@@ -1148,7 +1148,7 @@ public class SharedDriveConnector extend
 
 
   protected static void processSMBException(SmbException se, String documentIdentifier, String activity, String operation)
-    throws ACFException, ServiceInterruption
+    throws ManifoldCFException, ServiceInterruption
   {
     // At least some of these are transport errors, and should be treated as service
     // interruptions.
@@ -1159,7 +1159,7 @@ public class SharedDriveConnector extend
       // See if it's an interruption
       jcifs.util.transport.TransportException te = (jcifs.util.transport.TransportException)cause;
       if (te.getRootCause() != null && te.getRootCause() instanceof java.lang.InterruptedException)
-        throw new ACFException(te.getRootCause().getMessage(),te.getRootCause(),ACFException.INTERRUPTED);
+        throw new ManifoldCFException(te.getRootCause().getMessage(),te.getRootCause(),ManifoldCFException.INTERRUPTED);
       Logging.connectors.warn("JCIFS: Timeout "+activity+" for "+documentIdentifier+": retrying...",se);
       // Transport exceptions no longer abort when they give up, so we can't get notified that there is a problem.
 
@@ -1206,12 +1206,12 @@ public class SharedDriveConnector extend
     else if (se.getMessage().indexOf("Incorrect function") != -1)
     {
       Logging.connectors.error("JCIFS: Server does not support a required operation ("+operation+"?) for "+documentIdentifier);
-      throw new ACFException("Server does not support a required operation ("+operation+", possibly?) accessing document "+documentIdentifier,se);
+      throw new ManifoldCFException("Server does not support a required operation ("+operation+", possibly?) accessing document "+documentIdentifier,se);
     }
     else
     {
       Logging.connectors.error("SmbException thrown "+activity+" for "+documentIdentifier,se);
-      throw new ACFException("SmbException thrown: "+se.getMessage(),se);
+      throw new ManifoldCFException("SmbException thrown: "+se.getMessage(),se);
     }
   }
 
@@ -1273,7 +1273,7 @@ public class SharedDriveConnector extend
   }
 
   protected static int setPathMetadata(RepositoryDocument rd, String version, int index)
-    throws ACFException
+    throws ManifoldCFException
   {
     if (version.length() > index && version.charAt(index++) == '+')
     {
@@ -1297,7 +1297,7 @@ public class SharedDriveConnector extend
   /** Check status of connection.
   */
   public String check()
-    throws ACFException
+    throws ManifoldCFException
   {
     getSession();
     String serverURI = smbconnectionPath;
@@ -1329,7 +1329,7 @@ public class SharedDriveConnector extend
         }
         catch (InterruptedIOException e)
         {
-          throw new ACFException("Interrupted: "+e.getMessage(),e,ACFException.INTERRUPTED);
+          throw new ManifoldCFException("Interrupted: "+e.getMessage(),e,ManifoldCFException.INTERRUPTED);
         }
         catch (IOException e)
         {
@@ -1355,7 +1355,7 @@ public class SharedDriveConnector extend
   *@return true if it should be included.
   */
   protected boolean checkInclude(SmbFile file, String fileName, DocumentSpecification documentSpecification)
-    throws ACFException, ServiceInterruption
+    throws ManifoldCFException, ServiceInterruption
   {
     if (Logging.connectors.isDebugEnabled())
       Logging.connectors.debug("JCIFS: In checkInclude for '"+fileName+"'");
@@ -1410,7 +1410,7 @@ public class SharedDriveConnector extend
             }
             catch (NumberFormatException e)
             {
-              throw new ACFException("Bad number",e);
+              throw new ManifoldCFException("Bad number",e);
             }
           }
         }
@@ -1540,15 +1540,15 @@ public class SharedDriveConnector extend
     }
     catch (java.net.SocketTimeoutException e)
     {
-      throw new ACFException("Couldn't map to canonical path: "+e.getMessage(),e);
+      throw new ManifoldCFException("Couldn't map to canonical path: "+e.getMessage(),e);
     }
     catch (InterruptedIOException e)
     {
-      throw new ACFException("Interrupted: "+e.getMessage(),e,ACFException.INTERRUPTED);
+      throw new ManifoldCFException("Interrupted: "+e.getMessage(),e,ManifoldCFException.INTERRUPTED);
     }
     catch (IOException e)
     {
-      throw new ACFException("Couldn't map to canonical path: "+e.getMessage(),e);
+      throw new ManifoldCFException("Couldn't map to canonical path: "+e.getMessage(),e);
     }
     finally
     {
@@ -1568,7 +1568,7 @@ public class SharedDriveConnector extend
   */
   protected boolean wouldFileBeIncluded(String fileName, DocumentSpecification documentSpecification,
     boolean pretendIndexable)
-    throws ACFException
+    throws ManifoldCFException
   {
     if (Logging.connectors.isDebugEnabled())
       Logging.connectors.debug("JCIFS: In wouldFileBeIncluded for '"+fileName+"', pretendIndexable="+(pretendIndexable?"true":"false"));
@@ -1677,15 +1677,15 @@ public class SharedDriveConnector extend
     }
     catch (java.net.SocketTimeoutException e)
     {
-      throw new ACFException("Couldn't map to canonical path: "+e.getMessage(),e);
+      throw new ManifoldCFException("Couldn't map to canonical path: "+e.getMessage(),e);
     }
     catch (InterruptedIOException e)
     {
-      throw new ACFException("Interrupted: "+e.getMessage(),e,ACFException.INTERRUPTED);
+      throw new ManifoldCFException("Interrupted: "+e.getMessage(),e,ManifoldCFException.INTERRUPTED);
     }
     catch (IOException e)
     {
-      throw new ACFException("Couldn't map to canonical path: "+e.getMessage(),e);
+      throw new ManifoldCFException("Couldn't map to canonical path: "+e.getMessage(),e);
     }
     finally
     {
@@ -1701,7 +1701,7 @@ public class SharedDriveConnector extend
   *@return true if the file needs to be fingerprinted.
   */
   protected boolean checkNeedFileData(String fileName, DocumentSpecification documentSpecification)
-    throws ACFException
+    throws ManifoldCFException
   {
     return wouldFileBeIncluded(fileName,documentSpecification,true) != wouldFileBeIncluded(fileName,documentSpecification,false);
   }
@@ -1716,7 +1716,7 @@ public class SharedDriveConnector extend
   *@return true if the file should be ingested.
   */
   protected boolean checkIngest(File localFile, String fileName, DocumentSpecification documentSpecification, IFingerprintActivity activities)
-    throws ACFException, ServiceInterruption
+    throws ManifoldCFException, ServiceInterruption
   {
     if (Logging.connectors.isDebugEnabled())
       Logging.connectors.debug("JCIFS: In checkIngest for '"+fileName+"'");
@@ -1835,15 +1835,15 @@ public class SharedDriveConnector extend
     }
     catch (java.net.SocketTimeoutException e)
     {
-      throw new ACFException("Couldn't map to canonical path: "+e.getMessage(),e);
+      throw new ManifoldCFException("Couldn't map to canonical path: "+e.getMessage(),e);
     }
     catch (InterruptedIOException e)
     {
-      throw new ACFException("Interrupted: "+e.getMessage(),e,ACFException.INTERRUPTED);
+      throw new ManifoldCFException("Interrupted: "+e.getMessage(),e,ManifoldCFException.INTERRUPTED);
     }
     catch (IOException e)
     {
-      throw new ACFException("Couldn't map to canonical path: "+e.getMessage(),e);
+      throw new ManifoldCFException("Couldn't map to canonical path: "+e.getMessage(),e);
     }
     finally
     {
@@ -2544,7 +2544,7 @@ public class SharedDriveConnector extend
     protected int currentIndex = 0;
 
     public IdentifierStream(DocumentSpecification spec)
-      throws ACFException
+      throws ManifoldCFException
     {
       try
       {
@@ -2581,15 +2581,15 @@ public class SharedDriveConnector extend
       }
       catch (java.net.SocketTimeoutException e)
       {
-        throw new ACFException("Couldn't map to canonical path: "+e.getMessage(),e);
+        throw new ManifoldCFException("Couldn't map to canonical path: "+e.getMessage(),e);
       }
       catch (InterruptedIOException e)
       {
-        throw new ACFException("Interrupted: "+e.getMessage(),e,ACFException.INTERRUPTED);
+        throw new ManifoldCFException("Interrupted: "+e.getMessage(),e,ManifoldCFException.INTERRUPTED);
       }
       catch (IOException e)
       {
-        throw new ACFException("Could not get a canonical path: "+e.getMessage(),e);
+        throw new ManifoldCFException("Could not get a canonical path: "+e.getMessage(),e);
       }
     }
 
@@ -2597,7 +2597,7 @@ public class SharedDriveConnector extend
     *@return the next document identifier, or null if there are no more.
     */
     public String getNextIdentifier()
-      throws ACFException, ServiceInterruption
+      throws ManifoldCFException, ServiceInterruption
     {
       if (currentIndex == ids.length)
         return null;
@@ -2607,7 +2607,7 @@ public class SharedDriveConnector extend
     /** Close the stream.
     */
     public void close()
-      throws ACFException
+      throws ManifoldCFException
     {
       ids = null;
     }
@@ -2631,7 +2631,7 @@ public class SharedDriveConnector extend
   *@param tabsArray is an array of tab names.  Add to this array any tab names that are specific to the connector.
   */
   public void outputConfigurationHeader(IThreadContext threadContext, IHTTPOutput out, ConfigParams parameters, ArrayList tabsArray)
-    throws ACFException, IOException
+    throws ManifoldCFException, IOException
   {
     tabsArray.add("Server");
     out.print(
@@ -2681,7 +2681,7 @@ public class SharedDriveConnector extend
   *@param tabName is the current tab name.
   */
   public void outputConfigurationBody(IThreadContext threadContext, IHTTPOutput out, ConfigParams parameters, String tabName)
-    throws ACFException, IOException
+    throws ManifoldCFException, IOException
   {
     String server   = parameters.getParameter(org.apache.manifoldcf.crawler.connectors.sharedrive.SharedDriveParameters.server);
     if (server==null) server = "";
@@ -2738,7 +2738,7 @@ public class SharedDriveConnector extend
   *@return null if all is well, or a string error message if there is an error that should prevent saving of the connection (and cause a redirection to an error page).
   */
   public String processConfigurationPost(IThreadContext threadContext, IPostParameters variableContext, ConfigParams parameters)
-    throws ACFException
+    throws ManifoldCFException
   {
     String server = variableContext.getParameter("server");
     if (server != null)
@@ -2766,7 +2766,7 @@ public class SharedDriveConnector extend
   *@param parameters are the configuration parameters, as they currently exist, for this connection being configured.
   */
   public void viewConfiguration(IThreadContext threadContext, IHTTPOutput out, ConfigParams parameters)
-    throws ACFException, IOException
+    throws ManifoldCFException, IOException
   {
     out.print(
 "<table class=\"displaytable\">\n"+
@@ -2814,7 +2814,7 @@ public class SharedDriveConnector extend
   *@param tabsArray is an array of tab names.  Add to this array any tab names that are specific to the connector.
   */
   public void outputSpecificationHeader(IHTTPOutput out, DocumentSpecification ds, ArrayList tabsArray)
-    throws ACFException, IOException
+    throws ManifoldCFException, IOException
   {
     tabsArray.add("Paths");
     tabsArray.add("Security");
@@ -2958,7 +2958,7 @@ public class SharedDriveConnector extend
   *@param tabName is the current tab name.
   */
   public void outputSpecificationBody(IHTTPOutput out, DocumentSpecification ds, String tabName)
-    throws ACFException, IOException
+    throws ManifoldCFException, IOException
   {
     int i;
     int k;
@@ -3168,7 +3168,7 @@ public class SharedDriveConnector extend
           pathSoFar = "";
           childList = getChildFolderNames("");
           if (childList == null)
-            throw new ACFException("Can't find any children for root folder");
+            throw new ManifoldCFException("Can't find any children for root folder");
         }
         out.print(
 "          <input type=\"hidden\" name=\"specpath\" value=\""+org.apache.manifoldcf.ui.util.Encoder.attributeEscape(pathSoFar)+"\"/>\n"+
@@ -3206,7 +3206,7 @@ public class SharedDriveConnector extend
           );
         }
       }
-      catch (ACFException e)
+      catch (ManifoldCFException e)
       {
         e.printStackTrace();
         out.println(org.apache.manifoldcf.ui.util.Encoder.bodyEscape(e.getMessage()));
@@ -3687,7 +3687,7 @@ public class SharedDriveConnector extend
   *@return null if all is well, or a string error message if there is an error that should prevent saving of the job (and cause a redirection to an error page).
   */
   public String processSpecificationPost(IPostParameters variableContext, DocumentSpecification ds)
-    throws ACFException
+    throws ManifoldCFException
   {
     String x = variableContext.getParameter("pathcount");
     if (x != null)
@@ -3878,7 +3878,7 @@ public class SharedDriveConnector extend
             if (trialPath != null)
               path = trialPath;
           }
-          catch (ACFException e)
+          catch (ManifoldCFException e)
           {
             // Effectively, this just means we can't add a typein to the path right now.
           }
@@ -4182,7 +4182,7 @@ public class SharedDriveConnector extend
   *@param ds is the current document specification for this job.
   */
   public void viewSpecification(IHTTPOutput out, DocumentSpecification ds)
-    throws ACFException, IOException
+    throws ManifoldCFException, IOException
   {
     out.print(
 "<table class=\"displaytable\">\n"
@@ -4558,7 +4558,7 @@ public class SharedDriveConnector extend
   * @return an array of SmbFile
   */
   public SmbFile[] getShareNames(String serverURI)
-    throws ACFException
+    throws ManifoldCFException
   {
     getSession();
     SmbFile server = null;
@@ -4568,7 +4568,7 @@ public class SharedDriveConnector extend
     }
     catch (MalformedURLException e1)
     {
-      throw new ACFException("MalformedURLException tossed",e1);
+      throw new ManifoldCFException("MalformedURLException tossed",e1);
     }
     SmbFile[] shares = null;
     try
@@ -4581,7 +4581,7 @@ public class SharedDriveConnector extend
     }
     catch (SmbException e)
     {
-      throw new ACFException("SmbException tossed: "+e.getMessage(),e);
+      throw new ManifoldCFException("SmbException tossed: "+e.getMessage(),e);
     }
     return shares;
   }
@@ -4590,9 +4590,9 @@ public class SharedDriveConnector extend
   * Given a folder path, determine if the folder is in fact legal and accessible (and is a folder).
   * @param folder is the relative folder from the network root
   * @return the canonical folder name if valid, or null if not.
-  * @throws ACFException
+  * @throws ManifoldCFException
   */
-  public String validateFolderName(String folder) throws ACFException
+  public String validateFolderName(String folder) throws ManifoldCFException
   {
     getSession();
     //create new connection by appending to the old connection
@@ -4609,7 +4609,7 @@ public class SharedDriveConnector extend
     }
     catch (MalformedURLException e1)
     {
-      throw new ACFException("validateFolderName: Can't get parent file: " + uri,e1);
+      throw new ManifoldCFException("validateFolderName: Can't get parent file: " + uri,e1);
     }
 
     try
@@ -4632,24 +4632,24 @@ public class SharedDriveConnector extend
       }
       catch (ServiceInterruption si)
       {
-        throw new ACFException("Service interruption: "+si.getMessage(),si);
+        throw new ManifoldCFException("Service interruption: "+si.getMessage(),si);
       }
     }
     catch (MalformedURLException e)
     {
-      throw new ACFException("MalformedURLException tossed: "+e.getMessage(),e);
+      throw new ManifoldCFException("MalformedURLException tossed: "+e.getMessage(),e);
     }
     catch (java.net.SocketTimeoutException e)
     {
-      throw new ACFException("IOException tossed: "+e.getMessage(),e);
+      throw new ManifoldCFException("IOException tossed: "+e.getMessage(),e);
     }
     catch (InterruptedIOException e)
     {
-      throw new ACFException("Interrupted: "+e.getMessage(),e,ACFException.INTERRUPTED);
+      throw new ManifoldCFException("Interrupted: "+e.getMessage(),e,ManifoldCFException.INTERRUPTED);
     }
     catch (IOException e)
     {
-      throw new ACFException("IOException tossed: "+e.getMessage(),e);
+      throw new ManifoldCFException("IOException tossed: "+e.getMessage(),e);
     }
 
   }
@@ -4659,9 +4659,9 @@ public class SharedDriveConnector extend
   *
   * @param folder is the relative folder from the network root
   * @return array of child folder names
-  * @throws ACFException
+  * @throws ManifoldCFException
   */
-  public String[] getChildFolderNames(String folder) throws ACFException
+  public String[] getChildFolderNames(String folder) throws ManifoldCFException
   {
     getSession();
     //create new connection by appending to the old connection
@@ -4678,7 +4678,7 @@ public class SharedDriveConnector extend
     }
     catch (MalformedURLException e1)
     {
-      throw new ACFException("getChildFolderNames: Can't get parent file: " + uri,e1);
+      throw new ManifoldCFException("getChildFolderNames: Can't get parent file: " + uri,e1);
     }
 
     // add DFS support
@@ -4697,24 +4697,24 @@ public class SharedDriveConnector extend
       }
       catch (ServiceInterruption si)
       {
-        throw new ACFException("Service interruption: "+si.getMessage(),si);
+        throw new ManifoldCFException("Service interruption: "+si.getMessage(),si);
       }
     }
     catch (MalformedURLException e)
     {
-      throw new ACFException("MalformedURLException tossed: "+e.getMessage(),e);
+      throw new ManifoldCFException("MalformedURLException tossed: "+e.getMessage(),e);
     }
     catch (java.net.SocketTimeoutException e)
     {
-      throw new ACFException("IOException tossed: "+e.getMessage(),e);
+      throw new ManifoldCFException("IOException tossed: "+e.getMessage(),e);
     }
     catch (InterruptedIOException e)
     {
-      throw new ACFException("Interrupted: "+e.getMessage(),e,ACFException.INTERRUPTED);
+      throw new ManifoldCFException("Interrupted: "+e.getMessage(),e,ManifoldCFException.INTERRUPTED);
     }
     catch (IOException e)
     {
-      throw new ACFException("IOException tossed: "+e.getMessage(),e);
+      throw new ManifoldCFException("IOException tossed: "+e.getMessage(),e);
     }
 
     // populate a String array
@@ -4783,7 +4783,7 @@ public class SharedDriveConnector extend
     /** Document specification */
     protected DocumentSpecification spec;
     /** Exceptions that we saw.  These are saved here so that they can be rethrown when done */
-    protected ACFException lcfException = null;
+    protected ManifoldCFException lcfException = null;
     protected ServiceInterruption serviceInterruption = null;
 
     /** Constructor */
@@ -4833,7 +4833,7 @@ public class SharedDriveConnector extend
 
         return false;
       }
-      catch (ACFException e)
+      catch (ManifoldCFException e)
       {
         if (lcfException == null)
           lcfException = e;
@@ -4849,7 +4849,7 @@ public class SharedDriveConnector extend
 
     /** Check for exception, and throw if there is one */
     public void checkAndThrow()
-      throws ServiceInterruption, ACFException
+      throws ServiceInterruption, ManifoldCFException
     {
       if (lcfException != null)
         throw lcfException;

Modified: incubator/lcf/trunk/modules/connectors/jcifs/connector/src/main/java/org/apache/manifoldcf/crawler/connectors/sharedrive/SharedDriveHelpers.java
URL: http://svn.apache.org/viewvc/incubator/lcf/trunk/modules/connectors/jcifs/connector/src/main/java/org/apache/manifoldcf/crawler/connectors/sharedrive/SharedDriveHelpers.java?rev=1004255&r1=1004254&r2=1004255&view=diff
==============================================================================
--- incubator/lcf/trunk/modules/connectors/jcifs/connector/src/main/java/org/apache/manifoldcf/crawler/connectors/sharedrive/SharedDriveHelpers.java (original)
+++ incubator/lcf/trunk/modules/connectors/jcifs/connector/src/main/java/org/apache/manifoldcf/crawler/connectors/sharedrive/SharedDriveHelpers.java Mon Oct  4 14:32:19 2010
@@ -16,7 +16,7 @@
 */
 package org.apache.manifoldcf.crawler.connectors.sharedrive;
 
-import org.apache.manifoldcf.core.interfaces.ACFException;
+import org.apache.manifoldcf.core.interfaces.ManifoldCFException;
 
 import java.io.FileOutputStream;
 import java.io.FileInputStream;
@@ -54,7 +54,7 @@ public class SharedDriveHelpers
   *@param password is the password.
   */
   public SharedDriveHelpers(String serverName, String userName, String password)
-    throws ACFException
+    throws ManifoldCFException
   {
     try
     {
@@ -65,14 +65,14 @@ public class SharedDriveHelpers
     }
     catch (MalformedURLException e)
     {
-      throw new ACFException("Unable to access SMB/CIFS share: "+serverName, e, ACFException.SETUP_ERROR);
+      throw new ManifoldCFException("Unable to access SMB/CIFS share: "+serverName, e, ManifoldCFException.SETUP_ERROR);
     }
   }
 
   /** Close the connection.
   */
   public void close()
-    throws ACFException
+    throws ManifoldCFException
   {
     // Just let stuff go
     pa = null;
@@ -85,7 +85,7 @@ public class SharedDriveHelpers
   *@return the target path if the document is found, or "" if it is not.
   */
   public String lookupDocument(String targetPath)
-    throws ACFException
+    throws ManifoldCFException
   {
     try
     {
@@ -97,7 +97,7 @@ public class SharedDriveHelpers
     }
     catch (IOException e)
     {
-      throw new ACFException("IO exception: "+e.getMessage(),e);
+      throw new ManifoldCFException("IO exception: "+e.getMessage(),e);
     }
   }
 
@@ -108,7 +108,7 @@ public class SharedDriveHelpers
   *@return the target path.
   */
   public String addDocument(String targetPath, String sourceFile)
-    throws ACFException
+    throws ManifoldCFException
   {
     try
     {
@@ -150,7 +150,7 @@ public class SharedDriveHelpers
     }
     catch (IOException e)
     {
-      throw new ACFException("IO exception: "+e.getMessage(),e);
+      throw new ManifoldCFException("IO exception: "+e.getMessage(),e);
     }
   }
 
@@ -159,7 +159,7 @@ public class SharedDriveHelpers
   *       separated by "/" characters.
   */
   public void deleteDocument(String targetPath)
-    throws ACFException
+    throws ManifoldCFException
   {
     try
     {
@@ -169,7 +169,7 @@ public class SharedDriveHelpers
     }
     catch (IOException e)
     {
-      throw new ACFException("IO exception: "+e.getMessage(),e);
+      throw new ManifoldCFException("IO exception: "+e.getMessage(),e);
     }
   }
 
@@ -179,7 +179,7 @@ public class SharedDriveHelpers
   *@param userName is the user to add.
   */
   public void addUserToFolder(String targetPath, String userName)
-    throws ACFException
+    throws ManifoldCFException
   {
     // MHL
   }
@@ -190,7 +190,7 @@ public class SharedDriveHelpers
   *@param userName is the user to remove.
   */
   public void removeUserFromFolder(String targetPath, String userName)
-    throws ACFException
+    throws ManifoldCFException
   {
     // MHL
   }

Modified: incubator/lcf/trunk/modules/connectors/jdbc/connector/src/main/java/org/apache/manifoldcf/crawler/connectors/jdbc/IDynamicResultSet.java
URL: http://svn.apache.org/viewvc/incubator/lcf/trunk/modules/connectors/jdbc/connector/src/main/java/org/apache/manifoldcf/crawler/connectors/jdbc/IDynamicResultSet.java?rev=1004255&r1=1004254&r2=1004255&view=diff
==============================================================================
--- incubator/lcf/trunk/modules/connectors/jdbc/connector/src/main/java/org/apache/manifoldcf/crawler/connectors/jdbc/IDynamicResultSet.java (original)
+++ incubator/lcf/trunk/modules/connectors/jdbc/connector/src/main/java/org/apache/manifoldcf/crawler/connectors/jdbc/IDynamicResultSet.java Mon Oct  4 14:32:19 2010
@@ -34,10 +34,10 @@ public interface IDynamicResultSet
   *@return the immutable row description, or null if there is no such row.
   */
   public IResultRow getNextRow()
-    throws ACFException, ServiceInterruption;
+    throws ManifoldCFException, ServiceInterruption;
 
   /** Close this resultset.
   */
   public void close()
-    throws ACFException, ServiceInterruption;
+    throws ManifoldCFException, ServiceInterruption;
 }

Modified: incubator/lcf/trunk/modules/connectors/jdbc/connector/src/main/java/org/apache/manifoldcf/crawler/connectors/jdbc/JDBCConnection.java
URL: http://svn.apache.org/viewvc/incubator/lcf/trunk/modules/connectors/jdbc/connector/src/main/java/org/apache/manifoldcf/crawler/connectors/jdbc/JDBCConnection.java?rev=1004255&r1=1004254&r2=1004255&view=diff
==============================================================================
--- incubator/lcf/trunk/modules/connectors/jdbc/connector/src/main/java/org/apache/manifoldcf/crawler/connectors/jdbc/JDBCConnection.java (original)
+++ incubator/lcf/trunk/modules/connectors/jdbc/connector/src/main/java/org/apache/manifoldcf/crawler/connectors/jdbc/JDBCConnection.java Mon Oct  4 14:32:19 2010
@@ -55,7 +55,7 @@ public class JDBCConnection
   }
 
   protected static IResultRow readNextResultRowViaThread(ResultSet rs, ResultSetMetaData rsmd, String[] resultCols)
-    throws ACFException, ServiceInterruption
+    throws ManifoldCFException, ServiceInterruption
   {
     NextResultRowThread t = new NextResultRowThread(rs,rsmd,resultCols);
     try
@@ -66,9 +66,9 @@ public class JDBCConnection
       if (thr != null)
       {
         if (thr instanceof java.sql.SQLException)
-          throw new ACFException("Error fetching next JDBC result row: "+thr.getMessage(),thr);
-        else if (thr instanceof ACFException)
-          throw (ACFException)thr;
+          throw new ManifoldCFException("Error fetching next JDBC result row: "+thr.getMessage(),thr);
+        else if (thr instanceof ManifoldCFException)
+          throw (ManifoldCFException)thr;
         else if (thr instanceof ServiceInterruption)
           throw (ServiceInterruption)thr;
         else if (thr instanceof RuntimeException)
@@ -81,7 +81,7 @@ public class JDBCConnection
     catch (InterruptedException e)
     {
       t.interrupt();
-      throw new ACFException("Interrupted: "+e.getMessage(),e,ACFException.INTERRUPTED);
+      throw new ManifoldCFException("Interrupted: "+e.getMessage(),e,ManifoldCFException.INTERRUPTED);
     }
   }
 
@@ -127,7 +127,7 @@ public class JDBCConnection
   }
 
   protected static IResultRow readNextResultRow(ResultSet rs, ResultSetMetaData rsmd, String[] resultCols)
-    throws ACFException, ServiceInterruption
+    throws ManifoldCFException, ServiceInterruption
   {
     try
     {
@@ -139,12 +139,12 @@ public class JDBCConnection
     }
     catch (java.sql.SQLException e)
     {
-      throw new ACFException("Result set error: "+e.getMessage(),e);
+      throw new ManifoldCFException("Result set error: "+e.getMessage(),e);
     }
   }
 
   protected static void closeResultset(ResultSet rs)
-    throws ACFException, ServiceInterruption
+    throws ManifoldCFException, ServiceInterruption
   {
     try
     {
@@ -152,12 +152,12 @@ public class JDBCConnection
     }
     catch (java.sql.SQLException e)
     {
-      throw new ACFException("Exception closing resultset: "+e.getMessage(),e);
+      throw new ManifoldCFException("Exception closing resultset: "+e.getMessage(),e);
     }
   }
 
   protected static void closeStmt(Statement stmt)
-    throws ACFException, ServiceInterruption
+    throws ManifoldCFException, ServiceInterruption
   {
     try
     {
@@ -165,12 +165,12 @@ public class JDBCConnection
     }
     catch (java.sql.SQLException e)
     {
-      throw new ACFException("Exception closing statement: "+e.getMessage(),e);
+      throw new ManifoldCFException("Exception closing statement: "+e.getMessage(),e);
     }
   }
 
   protected static void closePS(PreparedStatement ps)
-    throws ACFException, ServiceInterruption
+    throws ManifoldCFException, ServiceInterruption
   {
     try
     {
@@ -178,7 +178,7 @@ public class JDBCConnection
     }
     catch (java.sql.SQLException e)
     {
-      throw new ACFException("Exception closing statement: "+e.getMessage(),e);
+      throw new ManifoldCFException("Exception closing statement: "+e.getMessage(),e);
     }
   }
 
@@ -186,7 +186,7 @@ public class JDBCConnection
   /** Test connection.
   */
   public void testConnection()
-    throws ACFException, ServiceInterruption
+    throws ManifoldCFException, ServiceInterruption
   {
     TestConnectionThread t = new TestConnectionThread();
     try
@@ -197,9 +197,9 @@ public class JDBCConnection
       if (thr != null)
       {
         if (thr instanceof java.sql.SQLException)
-          throw new ACFException("Error doing JDBC connection test: "+thr.getMessage(),thr);
-        else if (thr instanceof ACFException)
-          throw (ACFException)thr;
+          throw new ManifoldCFException("Error doing JDBC connection test: "+thr.getMessage(),thr);
+        else if (thr instanceof ManifoldCFException)
+          throw (ManifoldCFException)thr;
         else if (thr instanceof ServiceInterruption)
           throw (ServiceInterruption)thr;
         else if (thr instanceof RuntimeException)
@@ -211,7 +211,7 @@ public class JDBCConnection
     catch (InterruptedException e)
     {
       t.interrupt();
-      throw new ACFException("Interrupted: "+e.getMessage(),e,ACFException.INTERRUPTED);
+      throw new ManifoldCFException("Interrupted: "+e.getMessage(),e,ManifoldCFException.INTERRUPTED);
     }
   }
 
@@ -247,7 +247,7 @@ public class JDBCConnection
   /** Execute query.
   */
   public IDynamicResultSet executeUncachedQuery(String query, ArrayList params, int maxResults)
-    throws ACFException, ServiceInterruption
+    throws ManifoldCFException, ServiceInterruption
   {
     if (params == null)
       return new JDBCResultSet(query,maxResults);
@@ -258,7 +258,7 @@ public class JDBCConnection
   /** Execute operation.
   */
   public void executeOperation(String query, ArrayList params)
-    throws ACFException, ServiceInterruption
+    throws ManifoldCFException, ServiceInterruption
   {
     ExecuteOperationThread t = new ExecuteOperationThread(query,params);
     try
@@ -269,9 +269,9 @@ public class JDBCConnection
       if (thr != null)
       {
         if (thr instanceof java.sql.SQLException)
-          throw new ACFException("Exception doing connector query '"+query+"': "+thr.getMessage(),thr);
-        else if (thr instanceof ACFException)
-          throw (ACFException)thr;
+          throw new ManifoldCFException("Exception doing connector query '"+query+"': "+thr.getMessage(),thr);
+        else if (thr instanceof ManifoldCFException)
+          throw (ManifoldCFException)thr;
         else if (thr instanceof ServiceInterruption)
           throw (ServiceInterruption)thr;
         else if (thr instanceof RuntimeException)
@@ -283,7 +283,7 @@ public class JDBCConnection
     catch (InterruptedException e)
     {
       t.interrupt();
-      throw new ACFException("Interrupted: "+e.getMessage(),e,ACFException.INTERRUPTED);
+      throw new ManifoldCFException("Interrupted: "+e.getMessage(),e,ManifoldCFException.INTERRUPTED);
     }
   }
 
@@ -334,7 +334,7 @@ public class JDBCConnection
   * @param params ArrayList if params !=null, use preparedStatement
   */
   protected static IResultSet execute(Connection connection, String query, ArrayList params, boolean bResults, int maxResults)
-    throws ACFException, ServiceInterruption
+    throws ManifoldCFException, ServiceInterruption
   {
 
     ResultSet rs;
@@ -404,19 +404,19 @@ public class JDBCConnection
       }
 
     }
-    catch (ACFException e)
+    catch (ManifoldCFException e)
     {
       throw e;
     }
     catch (java.sql.SQLException e)
     {
-      throw new ACFException("Exception doing connector query '"+query+"': "+e.getMessage(),e);
+      throw new ManifoldCFException("Exception doing connector query '"+query+"': "+e.getMessage(),e);
     }
   }
 
   /** Read the current row from the resultset */
   protected static IResultRow readResultRow(ResultSet rs, ResultSetMetaData rsmd, String[] resultCols)
-    throws ACFException, ServiceInterruption
+    throws ManifoldCFException, ServiceInterruption
   {
     try
     {
@@ -468,12 +468,12 @@ public class JDBCConnection
     }
     catch (java.sql.SQLException e)
     {
-      throw new ACFException("Resultset error: "+e.getMessage(),e);
+      throw new ManifoldCFException("Resultset error: "+e.getMessage(),e);
     }
   }
 
   protected static String[] readColumnNames(ResultSetMetaData rsmd)
-    throws ACFException, ServiceInterruption
+    throws ManifoldCFException, ServiceInterruption
   {
     try
     {
@@ -493,13 +493,13 @@ public class JDBCConnection
     }
     catch (java.sql.SQLException e)
     {
-      throw new ACFException("Sql exception reading column names: "+e.getMessage(),e);
+      throw new ManifoldCFException("Sql exception reading column names: "+e.getMessage(),e);
     }
   }
 
   // Read data from a resultset
   protected static IResultSet getData(ResultSet rs, int maxResults)
-    throws ACFException, ServiceInterruption
+    throws ManifoldCFException, ServiceInterruption
   {
     try
     {
@@ -516,7 +516,7 @@ public class JDBCConnection
         {
           // This is an error situation; if a result with no columns is
           // necessary, bResults must be false!!!
-          throw new ACFException("Empty query, no columns returned",ACFException.GENERAL_ERROR);
+          throw new ManifoldCFException("Empty query, no columns returned",ManifoldCFException.GENERAL_ERROR);
         }
 
         while (rs.next() && (maxResults == -1 || maxResults > 0))
@@ -531,13 +531,13 @@ public class JDBCConnection
     }
     catch (java.sql.SQLException e)
     {
-      throw new ACFException("Resultset error: "+e.getMessage(),e);
+      throw new ManifoldCFException("Resultset error: "+e.getMessage(),e);
     }
   }
 
   // pass params to preparedStatement
   protected static void loadPS(PreparedStatement ps, ArrayList data)
-    throws java.sql.SQLException, ACFException
+    throws java.sql.SQLException, ManifoldCFException
   {
     if (data!=null)
     {
@@ -595,7 +595,7 @@ public class JDBCConnection
   /** Clean up parameters after query has been triggered.
   */
   protected static void cleanupParameters(ArrayList data)
-    throws ACFException
+    throws ManifoldCFException
   {
     if (data != null)
     {
@@ -614,7 +614,7 @@ public class JDBCConnection
   }
 
   protected static int findColumn(ResultSet rs, String name)
-    throws ACFException, ServiceInterruption
+    throws ManifoldCFException, ServiceInterruption
   {
     try
     {
@@ -627,7 +627,7 @@ public class JDBCConnection
   }
 
   protected static Blob getBLOB(ResultSet rs, int col)
-    throws ACFException, ServiceInterruption
+    throws ManifoldCFException, ServiceInterruption
   {
     try
     {
@@ -635,12 +635,12 @@ public class JDBCConnection
     }
     catch (java.sql.SQLException sqle)
     {
-      throw new ACFException("Error in getBlob("+col+"): "+sqle.getMessage(),sqle,ACFException.DATABASE_ERROR);
+      throw new ManifoldCFException("Error in getBlob("+col+"): "+sqle.getMessage(),sqle,ManifoldCFException.DATABASE_ERROR);
     }
   }
 
   protected static Clob getCLOB(ResultSet rs, int col)
-    throws ACFException, ServiceInterruption
+    throws ManifoldCFException, ServiceInterruption
   {
     try
     {
@@ -648,12 +648,12 @@ public class JDBCConnection
     }
     catch (java.sql.SQLException sqle)
     {
-      throw new ACFException("Error in getClob("+col+"): "+sqle.getMessage(),sqle,ACFException.DATABASE_ERROR);
+      throw new ManifoldCFException("Error in getClob("+col+"): "+sqle.getMessage(),sqle,ManifoldCFException.DATABASE_ERROR);
     }
   }
 
   protected static boolean isBLOB(ResultSetMetaData rsmd, int col)
-    throws ACFException, ServiceInterruption
+    throws ManifoldCFException, ServiceInterruption
   {
     try
     {
@@ -662,12 +662,12 @@ public class JDBCConnection
     }
     catch (java.sql.SQLException sqle)
     {
-      throw new ACFException("Error in isBlob("+col+"): "+sqle.getMessage(),sqle,ACFException.DATABASE_ERROR);
+      throw new ManifoldCFException("Error in isBlob("+col+"): "+sqle.getMessage(),sqle,ManifoldCFException.DATABASE_ERROR);
     }
   }
 
   protected static boolean isBinaryData(ResultSetMetaData rsmd, int col)
-    throws ACFException, ServiceInterruption
+    throws ManifoldCFException, ServiceInterruption
   {
     try
     {
@@ -677,12 +677,12 @@ public class JDBCConnection
     }
     catch (java.sql.SQLException sqle)
     {
-      throw new ACFException("Error in isBinaryData("+col+"): "+sqle.getMessage(),sqle,ACFException.DATABASE_ERROR);
+      throw new ManifoldCFException("Error in isBinaryData("+col+"): "+sqle.getMessage(),sqle,ManifoldCFException.DATABASE_ERROR);
     }
   }
 
   protected static boolean isCLOB(ResultSetMetaData rsmd, int col)
-    throws ACFException, ServiceInterruption
+    throws ManifoldCFException, ServiceInterruption
   {
     try
     {
@@ -691,12 +691,12 @@ public class JDBCConnection
     }
     catch (java.sql.SQLException sqle)
     {
-      throw new ACFException("Error in isClob("+col+"): "+sqle.getMessage(),sqle,ACFException.DATABASE_ERROR);
+      throw new ManifoldCFException("Error in isClob("+col+"): "+sqle.getMessage(),sqle,ManifoldCFException.DATABASE_ERROR);
     }
   }
 
   protected static Object getObject(ResultSet rs, ResultSetMetaData rsmd, int col)
-    throws ACFException, ServiceInterruption
+    throws ManifoldCFException, ServiceInterruption
   {
     Object result = null;
 
@@ -770,7 +770,7 @@ public class JDBCConnection
       case java.sql.Types.VARBINARY:
       case java.sql.Types.BINARY:
       case java.sql.Types.LONGVARBINARY:
-        throw new ACFException("Binary type is not a string, column = " + col,ACFException.GENERAL_ERROR);
+        throw new ManifoldCFException("Binary type is not a string, column = " + col,ManifoldCFException.GENERAL_ERROR);
         //break
 
       default :
@@ -784,7 +784,7 @@ public class JDBCConnection
     }
     catch (java.sql.SQLException e)
     {
-      throw new ACFException("Exception in getString(): "+e.getMessage(),e,ACFException.DATABASE_ERROR);
+      throw new ManifoldCFException("Exception in getString(): "+e.getMessage(),e,ManifoldCFException.DATABASE_ERROR);
     }
     return result;
   }
@@ -800,7 +800,7 @@ public class JDBCConnection
 
     /** Constructor */
     public JDBCResultSet(String query, int maxResults)
-      throws ACFException, ServiceInterruption
+      throws ManifoldCFException, ServiceInterruption
     {
       this.maxResults = maxResults;
       StatementQueryThread t = new StatementQueryThread(query);
@@ -812,9 +812,9 @@ public class JDBCConnection
         if (thr != null)
         {
           if (thr instanceof java.sql.SQLException)
-            throw new ACFException("Exception doing connector query '"+query+"': "+thr.getMessage(),thr);
-          else if (thr instanceof ACFException)
-            throw (ACFException)thr;
+            throw new ManifoldCFException("Exception doing connector query '"+query+"': "+thr.getMessage(),thr);
+          else if (thr instanceof ManifoldCFException)
+            throw (ManifoldCFException)thr;
           else if (thr instanceof ServiceInterruption)
             throw (ServiceInterruption)thr;
           else if (thr instanceof RuntimeException)
@@ -831,7 +831,7 @@ public class JDBCConnection
       catch (InterruptedException e)
       {
         t.interrupt();
-        throw new ACFException("Interrupted: "+e.getMessage(),e,ACFException.INTERRUPTED);
+        throw new ManifoldCFException("Interrupted: "+e.getMessage(),e,ManifoldCFException.INTERRUPTED);
       }
     }
 
@@ -839,7 +839,7 @@ public class JDBCConnection
     *@return the immutable row description, or null if there is no such row.
     */
     public IResultRow getNextRow()
-      throws ACFException, ServiceInterruption
+      throws ManifoldCFException, ServiceInterruption
     {
       if (maxResults == -1 || maxResults > 0)
       {
@@ -854,9 +854,9 @@ public class JDBCConnection
     /** Close this resultset.
     */
     public void close()
-      throws ACFException, ServiceInterruption
+      throws ManifoldCFException, ServiceInterruption
     {
-      ACFException rval = null;
+      ManifoldCFException rval = null;
       if (rs != null)
       {
         try
@@ -864,9 +864,9 @@ public class JDBCConnection
           closeResultset(rs);
           rs = null;
         }
-        catch (ACFException e)
+        catch (ManifoldCFException e)
         {
-          if (rval == null || e.getErrorCode() == ACFException.INTERRUPTED)
+          if (rval == null || e.getErrorCode() == ManifoldCFException.INTERRUPTED)
             rval = e;
         }
       }
@@ -877,9 +877,9 @@ public class JDBCConnection
           closeStmt(stmt);
           stmt = null;
         }
-        catch (ACFException e)
+        catch (ManifoldCFException e)
         {
-          if (rval == null || e.getErrorCode() == ACFException.INTERRUPTED)
+          if (rval == null || e.getErrorCode() == ManifoldCFException.INTERRUPTED)
             rval = e;
         }
       }
@@ -890,9 +890,9 @@ public class JDBCConnection
           JDBCConnectionFactory.releaseConnection(connection);
           connection = null;
         }
-        catch (ACFException e)
+        catch (ManifoldCFException e)
         {
-          if (rval == null || e.getErrorCode() == ACFException.INTERRUPTED)
+          if (rval == null || e.getErrorCode() == ManifoldCFException.INTERRUPTED)
             rval = e;
         }
       }
@@ -944,9 +944,9 @@ public class JDBCConnection
           catch (ServiceInterruption e2)
           {
           }
-          catch (ACFException e2)
+          catch (ManifoldCFException e2)
           {
-            if (e2.getErrorCode() == ACFException.INTERRUPTED)
+            if (e2.getErrorCode() == ManifoldCFException.INTERRUPTED)
               this.exception = e2;
             // Ignore
           }
@@ -964,9 +964,9 @@ public class JDBCConnection
           catch (ServiceInterruption e2)
           {
           }
-          catch (ACFException e2)
+          catch (ManifoldCFException e2)
           {
-            if (e2.getErrorCode() == ACFException.INTERRUPTED)
+            if (e2.getErrorCode() == ManifoldCFException.INTERRUPTED)
               this.exception = e2;
             // Ignore
           }
@@ -984,9 +984,9 @@ public class JDBCConnection
           catch (ServiceInterruption e2)
           {
           }
-          catch (ACFException e2)
+          catch (ManifoldCFException e2)
           {
-            if (e2.getErrorCode() == ACFException.INTERRUPTED)
+            if (e2.getErrorCode() == ManifoldCFException.INTERRUPTED)
               this.exception = e2;
             // Otherwise, ignore
           }
@@ -1041,7 +1041,7 @@ public class JDBCConnection
 
     /** Constructor */
     public JDBCPSResultSet(String query, ArrayList params, int maxResults)
-      throws ACFException, ServiceInterruption
+      throws ManifoldCFException, ServiceInterruption
     {
       this.maxResults = maxResults;
       this.params = params;
@@ -1056,9 +1056,9 @@ public class JDBCConnection
           // Cleanup of parameters happens even if exception doing query
           cleanupParameters(params);
           if (thr instanceof java.sql.SQLException)
-            throw new ACFException("Exception doing connector query '"+query+"': "+thr.getMessage(),thr);
-          else if (thr instanceof ACFException)
-            throw (ACFException)thr;
+            throw new ManifoldCFException("Exception doing connector query '"+query+"': "+thr.getMessage(),thr);
+          else if (thr instanceof ManifoldCFException)
+            throw (ManifoldCFException)thr;
           else if (thr instanceof ServiceInterruption)
             throw (ServiceInterruption)thr;
           else if (thr instanceof RuntimeException)
@@ -1076,7 +1076,7 @@ public class JDBCConnection
       {
         cleanupParameters(params);
         t.interrupt();
-        throw new ACFException("Interrupted: "+e.getMessage(),e,ACFException.INTERRUPTED);
+        throw new ManifoldCFException("Interrupted: "+e.getMessage(),e,ManifoldCFException.INTERRUPTED);
       }
     }
 
@@ -1084,7 +1084,7 @@ public class JDBCConnection
     *@return the immutable row description, or null if there is no such row.
     */
     public IResultRow getNextRow()
-      throws ACFException, ServiceInterruption
+      throws ManifoldCFException, ServiceInterruption
     {
       if (maxResults == -1 || maxResults > 0)
       {
@@ -1099,9 +1099,9 @@ public class JDBCConnection
     /** Close this resultset.
     */
     public void close()
-      throws ACFException, ServiceInterruption
+      throws ManifoldCFException, ServiceInterruption
     {
-      ACFException rval = null;
+      ManifoldCFException rval = null;
       if (rs != null)
       {
         try
@@ -1111,9 +1111,9 @@ public class JDBCConnection
         catch (ServiceInterruption e)
         {
         }
-        catch (ACFException e)
+        catch (ManifoldCFException e)
         {
-          if (rval == null || e.getErrorCode() == ACFException.INTERRUPTED)
+          if (rval == null || e.getErrorCode() == ManifoldCFException.INTERRUPTED)
             rval = e;
         }
         finally
@@ -1130,9 +1130,9 @@ public class JDBCConnection
         catch (ServiceInterruption e)
         {
         }
-        catch (ACFException e)
+        catch (ManifoldCFException e)
         {
-          if (rval == null || e.getErrorCode() == ACFException.INTERRUPTED)
+          if (rval == null || e.getErrorCode() == ManifoldCFException.INTERRUPTED)
             rval = e;
         }
         finally
@@ -1149,9 +1149,9 @@ public class JDBCConnection
         catch (ServiceInterruption e)
         {
         }
-        catch (ACFException e)
+        catch (ManifoldCFException e)
         {
-          if (rval == null || e.getErrorCode() == ACFException.INTERRUPTED)
+          if (rval == null || e.getErrorCode() == ManifoldCFException.INTERRUPTED)
             rval = e;
         }
         finally
@@ -1166,9 +1166,9 @@ public class JDBCConnection
           cleanupParameters(params);
           params = null;
         }
-        catch (ACFException e)
+        catch (ManifoldCFException e)
         {
-          if (rval == null || e.getErrorCode() == ACFException.INTERRUPTED)
+          if (rval == null || e.getErrorCode() == ManifoldCFException.INTERRUPTED)
             rval = e;
         }
       }
@@ -1222,9 +1222,9 @@ public class JDBCConnection
           catch (ServiceInterruption e2)
           {
           }
-          catch (ACFException e2)
+          catch (ManifoldCFException e2)
           {
-            if (e2.getErrorCode() == ACFException.INTERRUPTED)
+            if (e2.getErrorCode() == ManifoldCFException.INTERRUPTED)
               this.exception = e2;
           }
           finally
@@ -1241,9 +1241,9 @@ public class JDBCConnection
           catch (ServiceInterruption e2)
           {
           }
-          catch (ACFException e2)
+          catch (ManifoldCFException e2)
           {
-            if (e2.getErrorCode() == ACFException.INTERRUPTED)
+            if (e2.getErrorCode() == ManifoldCFException.INTERRUPTED)
               this.exception = e2;
           }
           finally
@@ -1260,9 +1260,9 @@ public class JDBCConnection
           catch (ServiceInterruption e2)
           {
           }
-          catch (ACFException e2)
+          catch (ManifoldCFException e2)
           {
-            if (e2.getErrorCode() == ACFException.INTERRUPTED)
+            if (e2.getErrorCode() == ManifoldCFException.INTERRUPTED)
               this.exception = e2;
           }
           finally

Modified: incubator/lcf/trunk/modules/connectors/jdbc/connector/src/main/java/org/apache/manifoldcf/crawler/connectors/jdbc/JDBCConnectionFactory.java
URL: http://svn.apache.org/viewvc/incubator/lcf/trunk/modules/connectors/jdbc/connector/src/main/java/org/apache/manifoldcf/crawler/connectors/jdbc/JDBCConnectionFactory.java?rev=1004255&r1=1004254&r2=1004255&view=diff
==============================================================================
--- incubator/lcf/trunk/modules/connectors/jdbc/connector/src/main/java/org/apache/manifoldcf/crawler/connectors/jdbc/JDBCConnectionFactory.java (original)
+++ incubator/lcf/trunk/modules/connectors/jdbc/connector/src/main/java/org/apache/manifoldcf/crawler/connectors/jdbc/JDBCConnectionFactory.java Mon Oct  4 14:32:19 2010
@@ -21,7 +21,7 @@ package org.apache.manifoldcf.crawler.co
 import org.apache.manifoldcf.core.interfaces.*;
 import org.apache.manifoldcf.agents.interfaces.*;
 import org.apache.manifoldcf.crawler.system.Logging;
-import org.apache.manifoldcf.crawler.system.ACF;
+import org.apache.manifoldcf.crawler.system.ManifoldCF;
 
 import java.util.*;
 import java.sql.*;
@@ -66,14 +66,14 @@ public class JDBCConnectionFactory
 
 
   public static Connection getConnection(String providerName, String host, String database, String userName, String password)
-    throws ACFException, ServiceInterruption
+    throws ManifoldCFException, ServiceInterruption
   {
     if (database.length() == 0)
       database = "_root_";
 
     String driverClassName = (String)driverMap.get(providerName);
     if (driverClassName == null)
-      throw new ACFException("Unrecognized jdbc provider: '"+providerName+"'");
+      throw new ManifoldCFException("Unrecognized jdbc provider: '"+providerName+"'");
 
     String instanceName = null;
     // Special for MSSQL: Allow database spec to contain an instance name too, in form:
@@ -111,7 +111,7 @@ public class JDBCConnectionFactory
         // Better include the credentials on the pool key, or we won't be able to change those and have it build new connections
         // The password value is SHA-1 hashed, because the pool driver reports the password in many exceptions and we don't want it
         // to be displayed.
-        poolKey += "/" + userName + "/" + ACF.hash(password);
+        poolKey += "/" + userName + "/" + ManifoldCF.hash(password);
 
         synchronized (_pool)
         {
@@ -134,7 +134,7 @@ public class JDBCConnectionFactory
           ConnectionPoolManager.URL_PREFIX + poolKey, null, null);
       }
       else
-        throw new ACFException("Can't get connection since pool driver did not initialize properly");
+        throw new ManifoldCFException("Can't get connection since pool driver did not initialize properly");
     }
     catch (java.sql.SQLException e)
     {
@@ -153,7 +153,7 @@ public class JDBCConnectionFactory
       }
       catch (java.sql.SQLException e2)
       {
-        throw new ACFException("Error getting connection: "+e2.getMessage(),e2,ACFException.SETUP_ERROR);
+        throw new ManifoldCFException("Error getting connection: "+e2.getMessage(),e2,ManifoldCFException.SETUP_ERROR);
       }
       // By definition, this must be a service interruption, because the direct route in setting up the connection succeeded.
       long currentTime = System.currentTimeMillis();
@@ -161,20 +161,20 @@ public class JDBCConnectionFactory
     }
     catch (java.lang.ClassNotFoundException e)
     {
-      throw new ACFException("Driver class not found: "+e.getMessage(),e,ACFException.SETUP_ERROR);
+      throw new ManifoldCFException("Driver class not found: "+e.getMessage(),e,ManifoldCFException.SETUP_ERROR);
     }
     catch (java.lang.InstantiationException e)
     {
-      throw new ACFException("Driver class not instantiable: "+e.getMessage(),e,ACFException.SETUP_ERROR);
+      throw new ManifoldCFException("Driver class not instantiable: "+e.getMessage(),e,ManifoldCFException.SETUP_ERROR);
     }
     catch (java.lang.IllegalAccessException e)
     {
-      throw new ACFException("Driver class not accessible: "+e.getMessage(),e,ACFException.SETUP_ERROR);
+      throw new ManifoldCFException("Driver class not accessible: "+e.getMessage(),e,ManifoldCFException.SETUP_ERROR);
     }
   }
 
   public static void releaseConnection(Connection c)
-    throws ACFException, ServiceInterruption
+    throws ManifoldCFException, ServiceInterruption
   {
     try
     {
@@ -182,7 +182,7 @@ public class JDBCConnectionFactory
     }
     catch (java.sql.SQLException e)
     {
-      throw new ACFException("Error releasing connection: "+e.getMessage(),e);
+      throw new ManifoldCFException("Error releasing connection: "+e.getMessage(),e);
     }
   }
--- incubator/lcf/trunk/modules/connectors/gts/connector/src/main/java/org/apache/manifoldcf/agents/output/gts/HttpPoster.java (original)
+++ incubator/lcf/trunk/modules/connectors/gts/connector/src/main/java/org/apache/manifoldcf/agents/output/gts/HttpPoster.java Mon Oct  4 14:32:19 2010
@@ -81,7 +81,7 @@ public class HttpPoster
     {
       secureSocketFactory = getSecureSocketFactory();
     }
-    catch (ACFException e)
+    catch (ManifoldCFException e)
     {
       // If we can't create, print and fail
       e.printStackTrace();
@@ -96,7 +96,7 @@ public class HttpPoster
   * @param postURI the uri to post the request to
   */
   public HttpPoster(String realm, String userID, String password, String postURI)
-    throws ACFException
+    throws ManifoldCFException
   {
     if (userID != null && userID.length() > 0 && password != null)
     {
@@ -106,7 +106,7 @@ public class HttpPoster
       }
       catch (java.io.UnsupportedEncodingException e)
       {
-        throw new ACFException("Couldn't convert to utf-8 bytes",e);
+        throw new ManifoldCFException("Couldn't convert to utf-8 bytes",e);
       }
       this.realm = realm;
     }
@@ -121,7 +121,7 @@ public class HttpPoster
     }
     catch (MalformedURLException murl)
     {
-      throw new ACFException("Bad url",murl);
+      throw new ManifoldCFException("Bad url",murl);
     }
 
     // set the port
@@ -136,16 +136,16 @@ public class HttpPoster
         port = 80;
     }
 
-    String x = ACF.getProperty(ingestBufferSizeProperty);
+    String x = ManifoldCF.getProperty(ingestBufferSizeProperty);
     if (x != null && x.length() > 0)
       buffersize = new Integer(x).intValue();
-    x = ACF.getProperty(ingestResponseRetryCount);
+    x = ManifoldCF.getProperty(ingestResponseRetryCount);
     if (x != null && x.length() > 0)
       responseRetries = new Integer(x).intValue();
-    x = ACF.getProperty(ingestResponseRetryInterval);
+    x = ManifoldCF.getProperty(ingestResponseRetryInterval);
     if (x != null && x.length() > 0)
       responseRetryWait = new Long(x).longValue();
-    x = ACF.getProperty(ingestRescheduleInterval);
+    x = ManifoldCF.getProperty(ingestRescheduleInterval);
     if (x != null && x.length() > 0)
       interruptionRetryTime = new Long(x).longValue();
   }
@@ -155,12 +155,12 @@ public class HttpPoster
   * @param documentURI is the document's uri.
   * @param document is the document structure to ingest.
   * @return true if the ingestion was successful, or false if the ingestion is illegal.
-  * @throws ACFException, ServiceInterruption
+  * @throws ManifoldCFException, ServiceInterruption
   */
   public boolean indexPost(String documentURI,
     String[] collections, String documentTemplate, String authorityNameString,
     RepositoryDocument document, IOutputAddActivity activities)
-    throws ACFException, ServiceInterruption
+    throws ManifoldCFException, ServiceInterruption
   {
     StringBuffer aclXml = new StringBuffer();
     writeACLs(aclXml,"share",document.getShareACL(),document.getShareDenyACL(),authorityNameString,activities);
@@ -205,8 +205,8 @@ public class HttpPoster
           {
             if (thr instanceof ServiceInterruption)
               throw (ServiceInterruption)thr;
-            if (thr instanceof ACFException)
-              throw (ACFException)thr;
+            if (thr instanceof ManifoldCFException)
+              throw (ManifoldCFException)thr;
             if (thr instanceof IOException)
               throw (IOException)thr;
             if (thr instanceof RuntimeException)
@@ -219,7 +219,7 @@ public class HttpPoster
         catch (InterruptedException e)
         {
           t.interrupt();
-          throw new ACFException("Interrupted: "+e.getMessage(),ACFException.INTERRUPTED);
+          throw new ManifoldCFException("Interrupted: "+e.getMessage(),ManifoldCFException.INTERRUPTED);
         }
       }
       catch (java.net.SocketTimeoutException ioe)
@@ -254,11 +254,11 @@ public class HttpPoster
       // Sleep for a time, and retry
       try
       {
-        ACF.sleep(10000L);
+        ManifoldCF.sleep(10000L);
       }
       catch (InterruptedException e)
       {
-        throw new ACFException("Interrupted: "+e.getMessage(),ACFException.INTERRUPTED);
+        throw new ManifoldCFException("Interrupted: "+e.getMessage(),ManifoldCFException.INTERRUPTED);
       }
       ioErrorRetry--;
 
@@ -270,7 +270,7 @@ public class HttpPoster
 
   /** Write acls into a stringbuffer */
   protected static void writeACLs(StringBuffer aclXml, String type, String[] acl, String[] denyAcl, String authorityNameString, IOutputAddActivity activities)
-    throws ACFException
+    throws ManifoldCFException
   {
     if (acl != null && acl.length > 0 || denyAcl != null && denyAcl.length > 0)
     {
@@ -306,7 +306,7 @@ public class HttpPoster
   /** Post a check request.
   */
   public void checkPost()
-    throws ACFException, ServiceInterruption
+    throws ManifoldCFException, ServiceInterruption
   {
     if (Logging.ingest.isDebugEnabled())
       Logging.ingest.debug("checkPost()");
@@ -328,8 +328,8 @@ public class HttpPoster
           {
             if (thr instanceof ServiceInterruption)
               throw (ServiceInterruption)thr;
-            if (thr instanceof ACFException)
-              throw (ACFException)thr;
+            if (thr instanceof ManifoldCFException)
+              throw (ManifoldCFException)thr;
             if (thr instanceof IOException)
               throw (IOException)thr;
             if (thr instanceof RuntimeException)
@@ -342,7 +342,7 @@ public class HttpPoster
         catch (InterruptedException e)
         {
           t.interrupt();
-          throw new ACFException("Interrupted: "+e.getMessage(),ACFException.INTERRUPTED);
+          throw new ManifoldCFException("Interrupted: "+e.getMessage(),ManifoldCFException.INTERRUPTED);
         }
       }
       catch (IOException ioe)
@@ -363,11 +363,11 @@ public class HttpPoster
       // Sleep for a time, and retry
       try
       {
-        ACF.sleep(10000L);
+        ManifoldCF.sleep(10000L);
       }
       catch (InterruptedException e)
       {
-        throw new ACFException("Interrupted",ACFException.INTERRUPTED);
+        throw new ManifoldCFException("Interrupted",ManifoldCFException.INTERRUPTED);
       }
       ioErrorRetry--;
 
@@ -379,7 +379,7 @@ public class HttpPoster
   *@param documentURI is the document's URI.
   */
   public void deletePost(String documentURI, IOutputRemoveActivity activities)
-    throws ACFException, ServiceInterruption
+    throws ManifoldCFException, ServiceInterruption
   {
     if (Logging.ingest.isDebugEnabled())
       Logging.ingest.debug("deletePost(): '" + documentURI + "'");
@@ -404,8 +404,8 @@ public class HttpPoster
           {
             if (thr instanceof ServiceInterruption)
               throw (ServiceInterruption)thr;
-            if (thr instanceof ACFException)
-              throw (ACFException)thr;
+            if (thr instanceof ManifoldCFException)
+              throw (ManifoldCFException)thr;
             if (thr instanceof IOException)
               throw (IOException)thr;
             if (thr instanceof RuntimeException)
@@ -418,7 +418,7 @@ public class HttpPoster
         catch (InterruptedException e)
         {
           t.interrupt();
-          throw new ACFException("Interrupted: "+e.getMessage(),ACFException.INTERRUPTED);
+          throw new ManifoldCFException("Interrupted: "+e.getMessage(),ManifoldCFException.INTERRUPTED);
         }
       }
       catch (IOException ioe)
@@ -440,11 +440,11 @@ public class HttpPoster
       // Sleep for a time, and retry
       try
       {
-        ACF.sleep(10000L);
+        ManifoldCF.sleep(10000L);
       }
       catch (InterruptedException e)
       {
-        throw new ACFException("Interrupted",ACFException.INTERRUPTED);
+        throw new ManifoldCFException("Interrupted",ManifoldCFException.INTERRUPTED);
       }
 
       ioErrorRetry--;
@@ -457,9 +457,9 @@ public class HttpPoster
   * Get the response code of the post
   * @param stream the stream the response is going to come from
   * @return the response string
-  * @throws ACFException
+  * @throws ManifoldCFException
   */
-  protected String getResponse(BufferedReader stream) throws ACFException, ServiceInterruption
+  protected String getResponse(BufferedReader stream) throws ManifoldCFException, ServiceInterruption
   {
     Logging.ingest.debug("Waiting for response stream");
     StringBuffer res = new StringBuffer();
@@ -490,7 +490,7 @@ public class HttpPoster
     }
     catch (InterruptedIOException e)
     {
-      throw new ACFException("Interrupted",ACFException.INTERRUPTED);
+      throw new ManifoldCFException("Interrupted",ManifoldCFException.INTERRUPTED);
     }
     catch (java.net.ConnectException e)
     {
@@ -567,7 +567,7 @@ public class HttpPoster
   /** Build a secure socket factory based on no keystore and a lax trust manager.
   * This allows use of SSL for privacy but not identification. */
   protected static javax.net.ssl.SSLSocketFactory getSecureSocketFactory()
-    throws ACFException
+    throws ManifoldCFException
   {
     try
     {
@@ -580,18 +580,18 @@ public class HttpPoster
     }
     catch (java.security.NoSuchAlgorithmException e)
     {
-      throw new ACFException("No such algorithm",e);
+      throw new ManifoldCFException("No such algorithm",e);
     }
     catch (java.security.KeyManagementException e)
     {
-      throw new ACFException("Key management exception",e);
+      throw new ManifoldCFException("Key management exception",e);
     }
   }
 
   /** Create a socket in a manner consistent with all of our specified parameters.
   */
   protected Socket createSocket(long responseRetryCount)
-    throws IOException, ACFException
+    throws IOException, ManifoldCFException
   {
     Socket socket;
     if (protocol.equals("https"))
@@ -607,7 +607,7 @@ public class HttpPoster
       }
       catch (IOException e)
       {
-        throw new ACFException("Couldn't set up SSL connection to ingestion API: "+e.getMessage(),e);
+        throw new ManifoldCFException("Couldn't set up SSL connection to ingestion API: "+e.getMessage(),e);
       }
     }
     else
@@ -929,7 +929,7 @@ public class HttpPoster
 
                   // A negative number means http error of some kind.
                   if (codeValue < 0)
-                    throw new ACFException("Http protocol error");
+                    throw new ManifoldCFException("Http protocol error");
 
                   // 200 means everything went OK
                   if (codeValue == 200)
@@ -945,11 +945,11 @@ public class HttpPoster
                   //    If the situation is (2), then we CAN'T retry if we already read any of the stream; therefore
                   //    we are forced to throw a "service interrupted" exception, and let the caller reschedule
                   //    the ingestion.
                   // 3) Something is wrong with the setup, e.g. bad credentials.  In this case we chuck a ACFException,
                   //    since this will abort the current activity entirely.
 
                   if (codeValue == 401)
-                    throw new ACFException("Bad credentials for ingestion",ACFException.SETUP_ERROR);
+                    throw new ManifoldCFException("Bad credentials for ingestion",ManifoldCFException.SETUP_ERROR);
 
                   if (codeValue >= 400 && codeValue < 500)
                   {
@@ -960,7 +960,7 @@ public class HttpPoster
                   // If this continues, we should indeed abort the job.  Retries should not go on indefinitely either; 2 hours is plenty
                   long currentTime = System.currentTimeMillis();
                   throw new ServiceInterruption("Error "+Integer.toString(codeValue)+" from ingestion request; ingestion will be retried again later",
-                    new ACFException("Ingestion HTTP error code "+Integer.toString(codeValue)),
+                    new ManifoldCFException("Ingestion HTTP error code "+Integer.toString(codeValue)),
                     currentTime + interruptionRetryTime,
                     currentTime + 2L * 60L * 60000L,
                     -1,
@@ -1000,7 +1000,7 @@ public class HttpPoster
         }
         catch (UnsupportedEncodingException ioe)
         {
-          throw new ACFException("Fatal ingestion error: "+ioe.getMessage(),ioe);
+          throw new ManifoldCFException("Fatal ingestion error: "+ioe.getMessage(),ioe);
         }
         catch (java.net.SocketTimeoutException ioe)
         {
@@ -1179,7 +1179,7 @@ public class HttpPoster
                   int codeValue = cd.getCodeValue();
 
                   if (codeValue < 0)
-                    throw new ACFException("Http protocol error");
+                    throw new ManifoldCFException("Http protocol error");
 
                   // 200 means everything went OK
                   if (codeValue == 200)
@@ -1187,13 +1187,13 @@ public class HttpPoster
 
                   // We ignore everything in the range from 400-500 now
                   if (codeValue == 401)
-                    throw new ACFException("Bad credentials for ingestion",ACFException.SETUP_ERROR);
+                    throw new ManifoldCFException("Bad credentials for ingestion",ManifoldCFException.SETUP_ERROR);
 
                   if (codeValue >= 400 && codeValue < 500)
                     return;
 
                   // Anything else means the document didn't delete.  Throw the error.
-                  throw new ACFException("Error deleting document: '"+res+"'");
+                  throw new ManifoldCFException("Error deleting document: '"+res+"'");
                 }
                 finally
                 {
@@ -1229,7 +1229,7 @@ public class HttpPoster
         }
         catch (UnsupportedEncodingException ioe)
         {
-          throw new ACFException("Fatal ingestion error: "+ioe.getMessage(),ioe);
+          throw new ManifoldCFException("Fatal ingestion error: "+ioe.getMessage(),ioe);
         }
         catch (InterruptedIOException ioe)
         {
@@ -1334,7 +1334,7 @@ public class HttpPoster
 
                   int codeValue = cd.getCodeValue();
                   if (codeValue < 0)
-                    throw new ACFException("Http protocol error");
+                    throw new ManifoldCFException("Http protocol error");
 
                   // 200 means everything went OK
                   if (codeValue == 200)
@@ -1342,10 +1342,10 @@ public class HttpPoster
 
                   // We ignore everything in the range from 400-500 now
                   if (codeValue == 401)
-                    throw new ACFException("Bad credentials for ingestion",ACFException.SETUP_ERROR);
+                    throw new ManifoldCFException("Bad credentials for ingestion",ManifoldCFException.SETUP_ERROR);
 
                   // Anything else means the info request failed.
-                  throw new ACFException("Error connecting to MetaCarta ingestion API: '"+res+"'");
+                  throw new ManifoldCFException("Error connecting to MetaCarta ingestion API: '"+res+"'");
                 }
                 finally
                 {
@@ -1381,7 +1381,7 @@ public class HttpPoster
         }
         catch (UnsupportedEncodingException ioe)
         {
-          throw new ACFException("Fatal ingestion error: "+ioe.getMessage(),ioe);
+          throw new ManifoldCFException("Fatal ingestion error: "+ioe.getMessage(),ioe);
         }
         catch (InterruptedIOException ioe)
         {
@@ -945,11 +945,11 @@ public class HttpPoster
                   //    we are forced to throw a "service interrupted" exception, and let the caller reschedule
                   //    the ingestion.
-                  // 3) Something is wrong with the setup, e.g. bad credentials.  In this case we chuck a ACFException,
+                  // 3) Something is wrong with the setup, e.g. bad credentials.  In this case we chuck a ManifoldCFException,
                   //    since this will abort the current activity entirely.
 

Modified: incubator/lcf/trunk/modules/connectors/jcifs/connector/src/main/java/org/apache/manifoldcf/crawler/connectors/sharedrive/GetConnectionInfo.java
URL: http://svn.apache.org/viewvc/incubator/lcf/trunk/modules/connectors/jcifs/connector/src/main/java/org/apache/manifoldcf/crawler/connectors/sharedrive/GetConnectionInfo.java?rev=1004255&r1=1004254&r2=1004255&view=diff
==============================================================================